@@ -19,6 +19,10 @@ namespace epimodels {
     #include "seirdconnected.hpp"
     #include "sirlogit.hpp"
     #include "diffnet.hpp"
+    #include "seirmixing.hpp"
+    #include "sirmixing.hpp"
+    #include "measlesquarantine.hpp"
+    #include "seirmixingquarantine.hpp"
 
 
 }
